==> lxqt-config_1.2.0.orig.tar.xz: lxqt-config-1.2.0/liblxqt-config-cursor/translations/lxqt-config-cursor_en_GB.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_GB">
<context>
    <name>SelectWnd</name>
    <message>
        <location filename="../selectwnd.ui" line="14"/>
        <source>LXQt Mouse Theme Configuration</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="46"/>
        <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="23"/>
        <source>&amp;Install New Theme...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="72"/>
        <source>LXQt session needs restart to view this change.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="91"/>
        <source>&amp;Remove Theme</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="111"/>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="231"/>
        <source>XCurTheme error</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="232"/>
        <source>You can&apos;t remove active theme!</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>WarningLabel</name>
    <message>
        <location filename="../warninglabel.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="44"/>
        <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="54"/>
        <source>Show...</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>XCursorThemeModel</name>
    <message>
        <location filename="../thememodel.cpp" line="61"/>
        <source>Name</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../thememodel.cpp" line="62"/>
        <source>Description</source>
        <translation></translation>
    </message>
</context>
</TS>

==> lxqt-config_1.4.0.orig.tar.xz: lxqt-config-1.4.0/liblxqt-config-cursor/translations/lxqt-config-cursor_en_GB.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_GB">
<context>
    <name>SelectWnd</name>
    <message>
        <location filename="../selectwnd.ui" line="14"/>
        <source>LXQt Mouse Theme Configuration</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="46"/>
        <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="23"/>
        <source>&amp;Install New Theme...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="72"/>
        <source>LXQt session needs restart to view this change.</source>
        <translation>LXQt session needs restart to view this change.</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="91"/>
        <source>&amp;Remove Theme</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="111"/>
        <source>Size</source>
        <translation>Size</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="230"/>
        <source>XCurTheme error</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="231"/>
        <source>You can&apos;t remove active theme!</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>WarningLabel</name>
    <message>
        <location filename="../warninglabel.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="44"/>
        <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="54"/>
        <source>Show...</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>XCursorThemeModel</name>
    <message>
        <location filename="../thememodel.cpp" line="61"/>
        <source>Name</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../thememodel.cpp" line="62"/>
        <source>Description</source>
        <translation></translation>
    </message>
</context>
</TS>
